@@ -13,6 +13,8 @@ class mf_movement():
         self.df_3_profits = pd.DataFrame(columns = ['n', 'Static_Profit', 'Unlimited_Dyn_Profit', 'Limited_Dyn_Profit'])
         self.dynamic_profit = 0
         self.df = pd.DataFrame()
+        self.Limited_Dyn_Profit = 0.0
+        self.Static_Profit = 0.0
         
     def empty_row_rmvl(self, df):
         import pandas as pd
@@ -227,13 +229,13 @@ class mf_movement():
         total_spent_on_shares = dfBuySell1['Bought'].sum()
         total_cost = initial_invest + total_spent_on_shares
         remaining_share_value = net_shares_remaining * dfBuySell1.iloc[x, 3]
-        total_gain = float(remaining_share_value) + int(total_received_from_shares * 100) / 100 ##############
-        profit_dynamic = total_gain - total_cost #####################################
+        total_gain = float(remaining_share_value) + int(total_received_from_shares * 100) / 100 
+        profit_dynamic = total_gain - total_cost 
         self.dynamic_profit = profit_dynamic
         dynamic_gain_ratio = profit_dynamic/total_cost
         dynamic_gain_percentage = '{:,.2%}'.format(dynamic_gain_ratio)
         ending_value = self.begin_shares * dfBuySell1.iloc[x, 3]
-        profit_static = ending_value - initial_invest  ###################################
+        profit_static = ending_value - initial_invest 
         static_gain = profit_static/initial_invest
         static_gain_percentage = '{:,.2%}'.format(static_gain)
         
@@ -288,6 +290,9 @@ class mf_movement():
         
     def section_defin_inflection_cmf(self, df): #this defines the range and resolution for the AV for evaluation
         import pandas as pd
+        #import grouping_sizePkg.grouping_sizePkg
+        #mf = grouping_sizePkg.grouping_sizePkg.mf_movement()
+        
         begin = int(input('What is the starting Averaging Value Position for the CMF? [Number greater than 10] ')) 
         end = int(input('What is the ending Averaging Value position for the CMF? [Number greater that starting #] ')) 
         resolution = int(input('What is the resolution? [integer value] '))   
@@ -303,7 +308,7 @@ class mf_movement():
             if 'level_0' in df.columns:
                 dfA = df.drop(['level_0'], axis = 1)
             
-            dfA = mf.cmf(df, begin_index) # = num_days is the number of days that are combined together to to produce the indicator
+            dfA = self.cmf(df, begin_index) # = num_days is the number of days that are combined together to to produce the indicator
             
             #### Dataframe clean up #####
             if 'index' in dfA.columns:
@@ -311,12 +316,12 @@ class mf_movement():
             if 'level_0' in dfA.columns:
                 dfA = dfA.drop(['level_0'], axis = 1)
                 
-            dfA = mf.empty_row_rmvl(dfA)
+            dfA = self.empty_row_rmvl(dfA)
             
             if 'index' in dfA.columns:
                 dfA = dfA.drop(['index'], axis = 1)
             
-            df1 = mf.buy_sell_signals(dfA) #246
+            df1 = self.buy_sell_signals(dfA) #246
             
             if 'Date' in df1.columns:
                 df1 = df1.drop(['Date'], axis = 1)
@@ -327,16 +332,14 @@ class mf_movement():
             
             df1 = df1.rename(columns = {'index':'Date'})
             
-            dfC = mf.shares_owned(dfA, begin_index) #for pos/neg cmf with limit of 0 to 1 share max
-            
-            
+            dfC = self.shares_owned(dfA, begin_index) #for pos/neg cmf with limit of 0 to 1 share max
             
             #### Writes the last index information to the summary table              ####
             
             if begin_index == end_index: #
                 summary_table = mf.buying_selling(df1) #336
             else:
-                mf.buying_selling(df1) #336
+                self.buying_selling(df1) #336
                 
             lst = [dfA, df1, dfC]
             del lst     # memory is released
